..
    This file is part of Invenio.
    Copyright (C) 2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _bootcamp:

Tutorials
=========

We maintain tutorials and training material for Invenio v3 in a separate
repository:

- `https://github.com/inveniosoftware/training <https://github.com/inveniosoftware/training/tree/v3.1>`_

Prerequisites
-------------------

- `Prerequisites <https://github.com/inveniosoftware/training/tree/v3.1/00-prerequisites>`_

Invenio at a glance
-------------------

- `Tutorial 01 - Getting started <https://github.com/inveniosoftware/training/tree/v3.1/01-getting-started>`_
- `Tutorial 02 - Tour of Invenio <https://github.com/inveniosoftware/training/tree/v3.1/02-invenio-tour>`_
- `Tutorial 03 - Infrastructure overview <https://github.com/inveniosoftware/training/tree/v3.1/03-infrastructure-tour>`_

Starting development with Invenio
---------------------------------

- `Tutorial 04 - Running Invenio <https://github.com/inveniosoftware/training/tree/v3.1/04-running-invenio>`_
- `Tutorial 05 - Customizing the look and feel <https://github.com/inveniosoftware/training/tree/v3.1/05-customizing-invenio>`_
- `Tutorial 06 - Developing with Invenio <https://github.com/inveniosoftware/training/tree/v3.1/06-developing-with-invenio>`_

Learning about data models
--------------------------

- `Tutorial 07 - Adding a new field <https://github.com/inveniosoftware/training/tree/v3.1/07-data-models-new-field>`_
- `Tutorial 08 - From scratch <https://github.com/inveniosoftware/training/tree/v3.1/08-data-models-from-scratch>`_
- `Tutorial 09 - Build a simple deposit form <https://github.com/inveniosoftware/training/tree/v3.1/09-deposit-form>`_
- `Tutorial 10 - Modify records before indexing <https://github.com/inveniosoftware/training/tree/v3.1/10-indexing-records>`_
- `Tutorial 11 - Linking records <https://github.com/inveniosoftware/training/tree/v3.1/11-linking-records>`_
- `Tutorial 12 - Managing access <https://github.com/inveniosoftware/training/tree/v3.1/12-managing-access>`_

Invenio in production
---------------------

- `Tutorial 13 - Securing your instance <https://github.com/inveniosoftware/training/tree/v3.1/13-securing-your-instance/>`_
- `Tutorial 14 - Deployment and monitoring <https://github.com/inveniosoftware/training/tree/v3.1/14-deployment-monitoring/>`_

Advanced topics
---------------

- `Tutorial 15 - Application architecture <https://github.com/inveniosoftware/training/tree/v3.1/15-application-architecture/>`_


How-to's
--------

.. toctree::
   :maxdepth: 2

   how-to/orcid-login
   how-to/build-a-module
